{
    package GCLang::PL::GCModels::GCmusics;

    use utf8;
###################################################
#
#  Copyright 2005-2007 Tian
#
#  This file is part of GCstar.
#
#  GCstar is free software; you can redistribute it and/or modify
#  it under the terms of the GNU General Public License as published by
#  the Free Software Foundation; either version 2 of the License, or
#  (at your option) any later version.
#
#  GCstar is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#  GNU General Public License for more details.
#
#  You should have received a copy of the GNU General Public License
#  along with GCstar; if not, write to the Free Software
#  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
#
###################################################
    
    use strict;
    use base 'Exporter';

    our @EXPORT = qw(%lang);

    our %lang = (
    
        CollectionDescription => 'Fonoteka',
        Items => sub {
          my $number = shift;
          return 'Album' if $number eq '1';
          return 'Albumy' if $number =~ /(?<!1)[2-4]$/;
          return 'Albumów';
        },

        NewItem => 'Nowy album',
    
        Unique => 'ISRC/EAN',
        Title => 'Tytuł',
        Cover => 'Okładka',
        Artist => 'Wykonawca',
        Format => 'Format',
        Running => 'Łączny czas',
        Release => 'Data wydania',
        Genre => 'Gatunek',

#For tracks list
        Tracks => 'Lista utworów',
        Number => 'Ścieżka',
        Track => 'Tytuł',
        Time => 'Czas trwania',

        Composer => 'Kompozytor',
        Producer => 'Producent',
        Playlist => 'Lista odtwarzania',
        Comments => 'Opinie',
        Label => 'Label',
        Url => 'Strona internetowa',

        General => 'Ogólne',
        Details => 'Szczegóły',
     );
}

1;
